@@ -1,6 +1,28 @@
+#
+# This file is part of Config-Model-OpenSsh
+#
+# This software is Copyright (c) 2011 by Dominique Dumont.
+#
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+#
 [
           {
+            'accept' => [
+                          '.*',
+                          {
+                            'value_type' => 'uniline',
+                            'summary' => 'boilerplate parameter that may hide a typo',
+                            'warn' => 'Unknow parameter please make sure there\'s no typo and contact the author',
+                            'type' => 'leaf'
+                          }
+                        ],
             'read_config' => [
+                               {
+                                 'backend' => 'OpenSsh::Sshd',
+                                 'config_dir' => '/etc/ssh'
+                               },
                                {
                                  'save' => 'backup',
                                  'file' => 'sshd_config',
@@ -11,34 +33,9 @@
                                                         'Match'
                                                       ],
                                  'config_dir' => '/etc/ssh'
-                               },
-                               {
-                                 'function' => 'sshd_read',
-                                 'backend' => 'custom',
-                                 'class' => 'Config::Model::OpenSsh',
-                                 'config_dir' => '/etc/ssh'
                                }
                              ],
             'name' => 'Sshd',
-            'write_config' => [
-                                {
-                                  'save' => 'backup',
-                                  'file' => 'sshd_config',
-                                  'backend' => 'augeas',
-                                  'sequential_lens' => [
-                                                         'HostKey',
-                                                         'Subsystem',
-                                                         'Match'
-                                                       ],
-                                  'config_dir' => '/etc/ssh'
-                                },
-                                {
-                                  'function' => 'sshd_write',
-                                  'backend' => 'custom',
-                                  'class' => 'Config::Model::OpenSsh',
-                                  'config_dir' => '/etc/ssh'
-                                }
-                              ],
             'element' => [
                            'AcceptEnv',
                            {
@@ -713,6 +710,16 @@ Alternatively, random early drop can be enabled by specifying the three colon se
                                            'LOCAL7'
                                          ]
                            },
+                           'KeepAlive',
+                           {
+                             'value_type' => 'enum',
+                             'status' => 'deprecated',
+                             'type' => 'leaf',
+                             'choice' => [
+                                           'no',
+                                           'yes'
+                                         ]
+                           },
                            'TCPKeepAlive',
                            {
                              'value_type' => 'enum',
@@ -721,6 +728,12 @@ Alternatively, random early drop can be enabled by specifying the three colon se
                                          'no' => 'disable TCP keepalive messages'
                                        },
                              'upstream_default' => 'yes',
+                             'migrate_from' => {
+                                                 'formula' => '$keep_alive',
+                                                 'variables' => {
+                                                                  'keep_alive' => '- KeepAlive'
+                                                                }
+                                               },
                              'type' => 'leaf',
                              'description' => 'Specifies whether the system should send TCP keepalive messages to the other side. If they are sent, death of the connection or crash of one of the machines will be properly noticed. However, this means that connections will die if the route is down temporarily, and some people find it annoying.  On the other hand, if TCP keepalives are not sent, sessions may hang indefinitely on the server, leaving "ghost" users and consuming server resources. This option was formerly called KeepAlive.',
                              'choice' => [
